==> dnet-actionmanager-service-4.0.1-20160415.162338-1-sources.jar: eu/dnetlib/actionmanager/inspector/ActionManagerController.java <==
package eu.dnetlib.actionmanager.inspector;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Set;
import javax.annotation.Resource;

import com.google.common.base.Function;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import eu.dnetlib.actionmanager.ActionManagerConstants.ACTION_TYPE;
import eu.dnetlib.actionmanager.actions.XsltInfoPackageAction;
import eu.dnetlib.actionmanager.common.Agent;
import eu.dnetlib.actionmanager.common.Agent.AGENT_TYPE;
import eu.dnetlib.actionmanager.common.Operation;
import eu.dnetlib.actionmanager.common.Provenance;
import eu.dnetlib.actionmanager.hbase.HBaseActionManagerCore;
import eu.dnetlib.actionmanager.hbase.HBaseJobLauncher;
import eu.dnetlib.actionmanager.rmi.ActionManagerException;
import eu.dnetlib.actionmanager.set.ActionManagerSet;
import eu.dnetlib.enabling.inspector.AbstractInspectorController;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;

@Controller
public class ActionManagerController extends AbstractInspectorController {

	private static final int DEFAULT_PAGE_SIZE = 10;

	@Resource
	private HBaseActionManagerCore core;

	@Resource
	private HBaseJobLauncher hbaseJobLauncher;

	@ModelAttribute(value = "types")
	public ACTION_TYPE[] listActionTypes() {
		return ACTION_TYPE.values();
	}

	@ModelAttribute(value = "provenances")
	public Provenance[] listProvenances() {
		return Provenance.values();
	}

	@ModelAttribute(value = "sets")
	public List<ActionManagerSet> listSets() throws ActionManagerException {
		return core.listAvailableSets();
	}

	@RequestMapping("/inspector/actions/listActions.do")
	public String listActions(final ModelMap map,
			@RequestParam(value = "type", required = false) final String stype,
			@RequestParam(value = "start", required = false) final String start) throws Exception {

		ACTION_TYPE type = stype == null ? ACTION_TYPE.all : ACTION_TYPE.valueOf(stype);
		String prefix = type == ACTION_TYPE.all ? null : type + "|";
		map.addAttribute("type", type);

		List<Map<String, String>> actions = core.getHbaseClient().retrieveRows(prefix, start, DEFAULT_PAGE_SIZE + 1);

		int size = actions.size();
		if (size > DEFAULT_PAGE_SIZE) {
			map.addAttribute("next", actions.remove(size - 1).get("rowId"));
		}

		map.addAttribute("actions", Lists.transform(actions, new Function<Map<String, String>, Map<String, Object>>() {

			@Override
			public Map<String, Object> apply(final Map<String, String> map) {
				return formatAction(map);
			}
		}));

		String template;

		switch (type) {
		case aac:
			template = "listAtomicActions";
			break;
		case pkg:
			template = "listInfoPackages";
			break;
		default:
			template = "listAll";
			break;
		}

		return "inspector/actions/" + template;
	}

	@SuppressWarnings("unchecked")
	private Map<String, Object> formatAction(final Map<String, String> map) {
		Map<String, Object> res = Maps.newHashMap();
		for (String key : map.keySet()) {
			if (key.equals("rowId")) {
				res.put("rowId", map.get(key));
			} else if (key.startsWith("date:")) {
				res.put("date", map.get(key));
			} else if (key.startsWith("set:")) {
				res.put("set", map.get(key));
			} else if (key.startsWith("operation:")) {
				res.put("operation", map.get(key));
			} else if (key.endsWith(":" + ACTION_TYPE.pkg)) {
				res.put("infoPackage", map.get(key).replaceAll("<", "&lt;").replaceAll(">", "&gt;"));
			} else if (key.startsWith("rel:")) {
				String nk = map.get(key).trim();
				if (!res.containsKey(nk)) {
					res.put(nk, new ArrayList<String>());
				}
				((List<String>) res.get(nk)).add(key.substring(4));
			} else if (key.startsWith("target:")) {
				res.put(key.replaceAll(":", "_"), map.get(key));
			} else {
				res.put(key, map.get(key));
			}
		}
		return res;
	}

	@RequestMapping("/inspector/actions/registerInfoPackage.do")
	public void registerInfoPackage(final ModelMap map,
			@RequestParam(value = "ruleId", required = false) final String ruleId,
			@RequestParam(value = "set", required = false) final String set,
			@RequestParam(value = "infoPackage", required = false) final String infoPackage,
			@RequestParam(value = "provenance", required = false) final String provenance,
			@RequestParam(value = "trust", required = false) final String trust,
			@RequestParam(value = "nsprefix", required = false) final String nsprefix) throws Exception {

		if (ruleId != null && !ruleId.isEmpty() && set != null && !set.isEmpty() && infoPackage != null && !infoPackage.isEmpty() && trust != null
				&& !trust.isEmpty() && provenance != null && !provenance.isEmpty() && nsprefix != null && !nsprefix.isEmpty()
				&& core.getActionFactory().getXslts().containsKey(ruleId)) {

			Agent agent = new Agent();
			agent.setId("inspector");
			agent.setName("inspector");
			agent.setType(AGENT_TYPE.human);

			final XsltInfoPackageAction action = core.applyInfoPackageAction(ruleId, set, agent, Operation.INSERT, infoPackage, Provenance.convert(provenance),
					trust, nsprefix);

			map.addAttribute("message", "Created infoPackageAction: " + action.getRowKey() + " ()");
		}

		map.addAttribute("rules", core.getActionFactory().getXslts().keySet());
		map.addAttribute("ruleId", ruleId);
		map.addAttribute("set", set);
		map.addAttribute("infoPackage", infoPackage);
		map.addAttribute("trust", trust);
		map.addAttribute("nsprefix", nsprefix);
	}

	@RequestMapping("/inspector/actions/deleteInfoPackage.do")
	public String deleteInfoPackage(final ModelMap map, @RequestParam(value = "id", required = false) final String id) throws Exception {
		core.deleteInfoPackageAction(id);
		return "redirect:listActions.do?type=" + ACTION_TYPE.pkg;
	}

	@RequestMapping("/inspector/actions/deleteSet.do")
	public String deleteSet(final ModelMap map, @RequestParam(value = "set", required = true) final String set) throws Exception {
		map.addAttribute("allSets", HBaseJobLauncher.ALL_SETS);
		if (set != null && !set.isEmpty()) {
			core.getInformationServiceClient().deleteSetProfile(set);
		}
		return "redirect:listSets.do";
	}

	@RequestMapping("/inspector/actions/createSet.do")
	public String createSet(final ModelMap map,
			@RequestParam(value = "id", required = true) final String id,
			@RequestParam(value = "name", required = true) final String name) throws Exception {
		core.getInformationServiceClient().registerSetProfile(new ActionManagerSet(id, name));
		return "redirect:listSets.do";
	}

	@RequestMapping("/inspector/actions/listSets.do")
	public void createSet(final ModelMap map) throws Exception {
		map.addAttribute("sets", core.listAvailableSets());
	}

	@RequestMapping("/inspector/actions/commit.do")
	public void commit(final ModelMap map, @RequestParam(value = "sets", required = false) final Set<String> sets) throws Exception {
		hbaseJobLauncher.executePromoteJob(sets, null);
		map.addAttribute("message", "Job launched !!!");
	}

	@RequestMapping("/inspector/actions/garbage.do")
	public void garbage(final ModelMap map) throws Exception {
		hbaseJobLauncher.executeGarbageJob(null);
		map.addAttribute("message", "Job launched !!!");
	}

}

==> dnet-actionmanager-service-5.2.2-20250415.132819-1325-sources.jar: eu/dnetlib/actionmanager/inspector/ActionManagerController.java <==
package eu.dnetlib.actionmanager.inspector;

import java.util.List;
import java.util.Set;

import eu.dnetlib.actionmanager.ActionManagerConstants.ACTION_TYPE;
import eu.dnetlib.actionmanager.blackboard.JobLauncher;
import eu.dnetlib.actionmanager.common.Provenance;
import eu.dnetlib.actionmanager.is.ISClient;
import eu.dnetlib.actionmanager.rmi.ActionManagerException;
import eu.dnetlib.actionmanager.set.ActionManagerSet;
import eu.dnetlib.enabling.inspector.AbstractInspectorController;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;

@Controller
public class ActionManagerController extends AbstractInspectorController {

	@Autowired
	private ISClient isClient;

	@Autowired
	private JobLauncher jobLauncher;

	@ModelAttribute(value = "types")
	public ACTION_TYPE[] listActionTypes() {
		return ACTION_TYPE.values();
	}

	@ModelAttribute(value = "provenances")
	public Provenance[] listProvenances() {
		return Provenance.values();
	}

	@ModelAttribute(value = "sets")
	public List<ActionManagerSet> listSets() throws ActionManagerException {
		return isClient.listSets();
	}

	@RequestMapping("/inspector/actions/createSet.do")
	public String createSet(final ModelMap map,
			@RequestParam(value = "id", required = true) final String id,
			@RequestParam(value = "name", required = true) final String name,
			@RequestParam(value = "directory", required = true) final String directory) throws Exception {
		isClient.registerSetProfile(new ActionManagerSet(id, name, directory));
		return "redirect:listSets.do";
	}

	@RequestMapping("/inspector/actions/listSets.do")
	public void createSet(final ModelMap map) throws Exception {
		map.addAttribute("sets", isClient.listValidSets());
	}

	@RequestMapping("/inspector/actions/commit.do")
	public void commit(final ModelMap map, @RequestParam(value = "sets", required = false) final Set<String> sets) throws Exception {
		jobLauncher.executePromoteFromHDFSJob(sets, null);
		map.addAttribute("message", "Job launched !!!");
	}

	@RequestMapping("/inspector/actions/garbage.do")
	public void garbage(final ModelMap map) throws Exception {
		jobLauncher.executeGarbageActions();
		map.addAttribute("message", "Job launched !!!");
	}

	@RequestMapping("/inspector/actions/deleteSet.do")
	public String deleteSet(final ModelMap map, @RequestParam(value = "set", required = true) final String set) throws Exception {
		map.addAttribute("allSets", JobLauncher.ALL_SETS);
		if (set != null && !set.isEmpty()) {
			isClient.deleteSetProfile(set);
		}
		return "redirect:listSets.do";
	}

	@RequestMapping("/inspector/actions/linkActionSetProfile.do")
	public String linkProfile(@RequestParam(value = "set", required = true) final String set) throws Exception {
		if (StringUtils.isBlank(set)) {
			throw new IllegalArgumentException("missing set id");
		}
		final String profileId = isClient.getProfileId(set);
		return "redirect:/mvc/inspector/index.do/db/DRIVER/ActionManagerSetDSResources/ActionManagerSetDSResourceType/" + profileId + "/show";
	}

}
